"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdapterBase = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
class AdapterBase {
    constructor(target) {
        this.target = target;
    }
    async loadFile(filePath) {
        if (!await fs_extra_1.default.pathExists(filePath)) {
            return {
                resources: {},
                targetLanguage: null,
            };
        }
        const content = await fs_extra_1.default.readFile(filePath, 'utf8');
        return await this.doLoadFile(content);
    }
    async loadLocales(locales) {
        if (!await fs_extra_1.default.pathExists(this.target)) {
            return locales.map(x => ({
                resources: {},
                targetLanguage: x,
            }));
        }
        const ret = [];
        for (const f of locales) {
            const t = await this.loadFile(path_1.default.join(this.target, `${f}.json`));
            t.targetLanguage = f;
            ret.push(t);
        }
        return ret;
    }
    async write(translation) {
        await fs_extra_1.default.ensureDir(this.target);
        const content = await this.contentFor(translation);
        const toFile = path_1.default.join(this.target, translation.targetLanguage + '.json');
        await fs_extra_1.default.writeFile(toFile, content, 'utf8');
    }
}
exports.AdapterBase = AdapterBase;
//# sourceMappingURL=adapter-base.js.map