"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadLocaleFrom = exports.getAdapter = void 0;
const xliff_1 = require("./xliff");
const json_1 = require("./json");
function getAdapter(format, dir) {
    switch (format) {
        case 'xliff':
            return new xliff_1.XliffAdapter(dir);
        case 'json':
            return new json_1.JsonAdapter(dir);
        default:
            throw new Error('Unknown translation format: ' + format);
    }
}
exports.getAdapter = getAdapter;
async function loadLocaleFrom(path) {
    const [ext] = /\.[a-z]+$/.exec(path.toLowerCase()) || [null];
    let adapter;
    switch (ext) {
        case '.json':
            adapter = new json_1.JsonAdapter(null);
            break;
        case '.xlf':
            adapter = new xliff_1.XliffAdapter(null);
            break;
        default:
            return null;
    }
    return await adapter.loadFile(path);
}
exports.loadLocaleFrom = loadLocaleFrom;
//# sourceMappingURL=index.js.map