"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultLocale = void 0;
const literal_1 = require("./literal");
const utils_1 = require("../cli/utils");
const locale_list_1 = require("./locale-list");
const utils_2 = require("./utils");
const emptyStringAutoId = utils_2.autoGenerateId([]);
class DefaultLocale {
    constructor(id) {
        this.id = id;
        this.literals = new literal_1.LiteralLocalizer(this);
        this.code = utils_1.getLocaleCode(id);
    }
    localize(id, parts, placeholders) {
        const existing = locale_list_1.getLocale(this.id);
        if (existing) {
            const exist = existing.localize(id, parts, placeholders);
            if (exist) {
                return exist;
            }
        }
        if (!parts || !placeholders) {
            // special case for empty string, which could not be translated.
            if (id === emptyStringAutoId) {
                return '';
            }
            throw new Error(`The smartloc string "${id}" cannot be translated to your default locale. It is likely that is has been deserialized. In order to support deserialized strings, you MUST load your default locale as a classic locale. nb: To generate your default locale translation file through smartloc CLI, use --generateDefault option`);
        }
        const result = [];
        // interleave the literals with the placeholders
        for (let i = 0; i < placeholders.length; i++) {
            result.push(parts[i]);
            result.push(this.literals.localize(placeholders[i]));
        }
        // add the last literal
        result.push(parts[parts.length - 1]);
        return result.join('');
    }
}
exports.DefaultLocale = DefaultLocale;
//# sourceMappingURL=default-locale.js.map