"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listLocales = exports.getLocale = exports.addLocale = exports.removeLocale = exports.clearLocales = exports.getDefaultLocale = exports.setDefaultLocale = void 0;
const default_locale_1 = require("./default-locale");
const locale_1 = require("./locale");
let locales = {};
let defaultLocale;
/** Defines the locale used in code */
function setDefaultLocale(localeId) {
    defaultLocale = new default_locale_1.DefaultLocale(localeId);
}
exports.setDefaultLocale = setDefaultLocale;
function getDefaultLocale() {
    return defaultLocale;
}
exports.getDefaultLocale = getDefaultLocale;
/** Resets all locales */
function clearLocales() {
    locales = {};
}
exports.clearLocales = clearLocales;
/** Remove a locale */
function removeLocale(id) {
    id = id.toLowerCase();
    const existing = locales[id];
    if (!existing) {
        return;
    }
    delete locales[id];
    const bl = baseLocale(id);
    if (bl && locales[bl] === existing) {
        delete locales[bl];
    }
}
exports.removeLocale = removeLocale;
/**
 * Adds translations
 * @param id Locale ID (ex: 'en', or 'en-US')
 * @param localeDef Translations (string id as key, formatted string as values - ex : {myId: 'Translated {0} text {1}'})
 * @param merge If true, then the translations will be merged with already existing translations.
 */
function addLocale(id, localeDef, merge) {
    id = id.toLowerCase();
    let loc = locales[id];
    if (loc) {
        if (!merge) {
            throw new Error(`There already is a locale '${id}' defined. Set the 'merge' argument to 'true' if you want to add translations`);
        }
        loc.localeDef = {
            ...loc.localeDef,
            ...localeDef,
        };
        return;
    }
    loc = locales[id] = new locale_1.Locale(id, localeDef);
    const bl = baseLocale(id);
    if (bl && !locales[bl]) {
        locales[bl] = loc;
    }
}
exports.addLocale = addLocale;
function getLocale(id) {
    if (!id) {
        return null;
    }
    const found = locales[id];
    if (found) {
        return found;
    }
    // if given "en-US", then try to downgrade to a non specific language.
    const bl = baseLocale(id);
    return bl && locales[bl] || null;
}
exports.getLocale = getLocale;
function baseLocale(l) {
    const m = /^([a-zA-Z]+)\-[a-zA-Z]+$/.exec(l);
    return (m === null || m === void 0 ? void 0 : m[1]) || null;
}
function* listLocales() {
    yield* Object.keys(locales);
    yield defaultLocale.id;
}
exports.listLocales = listLocales;
//# sourceMappingURL=locale-list.js.map