import { ILocaleDef, LocLiteral, LocStr } from './interfaces';
export interface SerializationContextOptions {
    /** HOw non self-descriptive (MultiLoc, SingleLoc, ...) will be transformed. Defaults to 'id'.
     *
     * id => will serialize its ID ... the context of deserialization will be required to have the given translation
     * skip => will be left as it (=> serialization will translate it)
     * toMulti => translates to all registered languages, and serializes as a 'multi'
     */
    nonSelfDescriptive?: 'skip' | 'toMulti' | 'id';
}
/**
 * Execute something in the given locales context.
 * @param acceptLanguages The accepted languages, by order of preference
 * @param action Action to perform (usually a JSON.serialize() or a .toString() operation)
 **/
export declare function withLocales<T = void>(acceptLanguages: string[], action: () => T): T;
/**
 * Execute something in a context where .toJson() loc strings
 * will be serialized into a form that is parsable via jsonParseLocalized()
 */
export declare function withSerializationContext<T = void>(action: () => T, options?: SerializationContextOptions): T;
export declare class TransformedLoc implements LocStr {
    private parent;
    private transformer;
    get id(): string;
    constructor(parent: LocStr, transformer: (x: string) => string);
    toJSON(): string;
    toString(locale?: string | ILocaleDef): string;
    transform(transformer: (x: string) => string): LocStr;
}
/**
 * A localizable string instance
 */
export declare class SmartLoc implements LocStr {
    id: string;
    private literals;
    private placeholders;
    constructor(id: string, literals: TemplateStringsArray, placeholders: LocLiteral[]);
    toJSON(): {};
    toString(locale?: string | ILocaleDef): string;
    transform(transformer: (x: string) => string): LocStr;
}
/** A loc string that has only one translation for all locales */
export declare class SingleLoc implements LocStr {
    text: string;
    readonly id: string;
    constructor(text: string);
    toJSON(): string;
    toString(): string;
    transform(transformer: (x: string) => string): LocStr;
}
/** A given set of translations */
export declare class MultiLoc implements LocStr {
    translations: {
        [locale: string]: string;
    };
    readonly id: string;
    constructor(translations: {
        [locale: string]: string;
    });
    toJSON(): {};
    toString(locale?: string | ILocaleDef): string;
    transform(transformer: (x: string) => string): LocStr;
}
