"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const accept_language_parser_1 = __importDefault(require("accept-language-parser"));
const supportedMethods = [
    { key: 'json', },
    { key: 'jsonp', },
    { key: 'send', fn: (v) => _1.isLocStr(v) ? v.toString() : v },
];
/**
 * Express middleware that will translate calls to .send(), .json() (etc...) based on the Accept-Language request header.
 */
function default_1(options) {
    const { errorLogger, customLocaleResolver, waitFor } = options !== null && options !== void 0 ? options : {};
    let waiter = waitFor;
    return function (req, res, next) {
        let locales;
        function serve() {
            var _a, _b;
            waiter = null;
            try {
                // === resolve locales from custom resolver
                if (!locales) {
                    const cust = customLocaleResolver(req);
                    if (typeof cust === 'string') {
                        locales = [cust];
                    }
                    else if (cust instanceof Array) {
                        locales = cust;
                    }
                    else if (cust) {
                        cust.then(resCust => {
                            if (typeof resCust === 'string') {
                                resCust = [resCust];
                            }
                            locales = resCust !== null && resCust !== void 0 ? resCust : [];
                            serve();
                        }, e => {
                            errorLogger === null || errorLogger === void 0 ? void 0 : errorLogger(e);
                            serve();
                        });
                        return; // defered => method will be called again later.
                    }
                }
                // === resolve locales from headers
                if (!locales || !locales.length) {
                    const lh = (_a = req === null || req === void 0 ? void 0 : req.headers) === null || _a === void 0 ? void 0 : _a['accept-language'];
                    if (!lh) {
                        next();
                        return; // => no locale... just serve without patching
                    }
                    locales = (_b = accept_language_parser_1.default.parse(lh)) === null || _b === void 0 ? void 0 : _b.map(x => x.region ? `${x.code}-${x.region}` : x.code);
                }
                // === override methods that sends potentially translatable content
                for (const { key, fn } of supportedMethods) {
                    const orig = res[key];
                    res[key] = function (fst, ...args) {
                        return _1.withLocales(locales, () => {
                            return orig.call(this, fn ? fn(fst) : fst, ...args);
                        });
                    };
                }
                next();
                return;
            }
            catch (e) {
                errorLogger === null || errorLogger === void 0 ? void 0 : errorLogger(e);
                next();
            }
        }
        ;
        // === serve if nothing to wait
        if (!waiter) {
            serve();
        }
        else {
            waiter.then(serve, serve);
        }
    };
}
exports.default = default_1;
//# sourceMappingURL=express.js.map