"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadLocale = exports.loadAllLocales = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const adapters_1 = require("../adapters");
const locale_list_1 = require("../core/locale-list");
/**
 * Loads all locales generated from CLI
 * @param dirPath The file directory where to look for translation
 * @param merge If true, then the translations will be merged with already existing translations.
 */
async function loadAllLocales(dirPath, merge) {
    for (const f of await fs_extra_1.default.readdir(dirPath)) {
        await loadLocale(path_1.default.join(dirPath, f), merge);
    }
}
exports.loadAllLocales = loadAllLocales;
/**
 * Loads a locale generated from CLI
 * @param filePath The file path to load
 * @param merge If true, then the translations will be merged with already existing translations.
 */
async function loadLocale(filePath, merge) {
    const locale = await adapters_1.loadLocaleFrom(filePath);
    if (!locale) {
        return false;
    }
    const transformed = convertLocale(locale);
    locale_list_1.addLocale(locale.targetLanguage, transformed, merge);
    return true;
}
exports.loadLocale = loadLocale;
function convertLocale(locale) {
    const ret = {};
    for (const [k, v] of Object.entries(locale.resources)) {
        ret[k] = v.target;
    }
    return ret;
}
//# sourceMappingURL=load.js.map